@@ -178,7 +178,8 @@ enum firetalk_error {
 	FE_DUPEROOM,
 	FE_IOERROR,
 	FE_BADHANDLE,
-	FE_TIMEOUT
+	FE_TIMEOUT,
+	FE_MESSAGETRUNCATED
 };
 
 
