@@ -1,7 +1,7 @@
 /*
 *
 * centericq core routines
-* $Id: centericq.cc,v 1.193 2004/11/09 23:49:59 konst Exp $
+* $Id: centericq.cc,v 1.195 2005/01/26 23:52:47 konst Exp $
 *
 * Copyright (C) 2001-2003 by Konstantin Klyagin <konst@konst.org.ua>
 *
@@ -367,6 +367,22 @@ void centericq::mainloop() {
 		face.userinfoexternal(c->getdesc());
 		break;
 
+	    case ACT_PGPSWITCH:
+		c->setusepgpkey(!c->getusepgpkey());
+		break;
+
+	    case ACT_PGPKEY:
+		text = c->getpgpkey();
+
+		if(!text.empty()) {
+		    c->setpgpkey("");
+		} else {
+		    if(face.selectpgpkey(text, false))
+			c->setpgpkey(text);
+		}
+
+		break;
+
 	    case ACT_MSG:
 	    case 0:
 		if(conf.getchatmode(c->getdesc().pname)) {
@@ -1515,7 +1531,7 @@ void centericq::exectimers() {
 		    if(hook.online()) {
 			hook.disconnect();
 
-		    } else if(conf.getstatus(pname) != offline) {
+		    } else if(hook.getmanualstatus() != offline) {
 			if(conf.enoughdiskspace() && !manager.isopen()) {
 			    hook.connect();
 			}
