@@ -59,7 +59,7 @@ class jabberhook: public abstracthook {
 
 	vector<pair<string, string> > getservparams(const string &agentname, agent::param_type pt) const;
 
-	void setjabberstatus(imstatus st, const string &msg);
+	void setjabberstatus(imstatus st, string msg);
 	void sendvisibility();
 
 	void sendnewuser(const imcontact &c, bool report);
@@ -71,7 +71,7 @@ class jabberhook: public abstracthook {
 	void postlogin();
 	void gotroster(xmlnode x);
 	void gotvcard(const imcontact &ic, xmlnode v);
-	void gotmessage(const string &type, const string &from, const string &body);
+	void gotmessage(const string &type, const string &from, const string &body, const string &enc);
 	void gotversion(const imcontact &ic, xmlnode x);
 
 	bool isourid(const string &jid);
@@ -131,6 +131,8 @@ class jabberhook: public abstracthook {
 
 	void requestversion(const imcontact &c);
 	void renamegroup(const string &oldname, const string &newname);
+
+	void ouridchanged(const icqconf::imaccount &ia);
 };
 
 extern jabberhook jhook;
