@@ -1,9 +1,9 @@
 /*
 *
 * centericq livejournal protocol handling class (sick)
-* $Id: ljhook.cc,v 1.24 2004/02/01 17:52:10 konst Exp $
+* $Id: ljhook.cc,v 1.28 2004/11/11 13:42:05 konst Exp $
 *
-* Copyright (C) 2003 by Konstantin Klyagin <konst@konst.org.ua>
+* Copyright (C) 2003-2004 by Konstantin Klyagin <konst@konst.org.ua>
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
@@ -48,9 +48,10 @@ void ljhook::init() {
     manualstatus = conf.getstatus(proto);
     httpcli.messageack.connect(this, &ljhook::messageack_cb);
     httpcli.socket.connect(this, &ljhook::socket_cb);
-#ifdef DEBUG
-    httpcli.logger.connect(this, &ljhook::logger_cb);
-#endif
+
+    if(conf.getdebug())
+	httpcli.logger.connect(this, &ljhook::logger_cb);
+
     journals = vector<string>(1, conf.getourid(proto).nickname);
 }
 
@@ -64,9 +65,10 @@ void ljhook::connect() {
 
     httpcli.setProxyServerHost(conf.gethttpproxyhost());
     httpcli.setProxyServerPort(conf.gethttpproxyport());
-    if (!conf.gethttpproxyuser().empty()) {
-	    httpcli.setProxyServerUser(conf.gethttpproxyuser());
-	    httpcli.setProxyServerPasswd(conf.gethttpproxypasswd());
+
+    if(!conf.gethttpproxyuser().empty()) {
+	httpcli.setProxyServerUser(conf.gethttpproxyuser());
+	httpcli.setProxyServerPasswd(conf.gethttpproxypasswd());
     }
 
     HTTPRequestEvent *ev = new HTTPRequestEvent(baseurl, HTTPRequestEvent::POST);
@@ -89,8 +91,9 @@ void ljhook::connect() {
     self = imcontact(username + "@lj", livejournal);
 
     fonline = true;
-    httpcli.SendEvent(ev);
+
     sent[ev] = reqLogin;
+    httpcli.SendEvent(ev);
 
     moods = vector<string>(1, "");
     pictures = vector<string>(1, "");
@@ -322,8 +325,9 @@ void ljhook::sendnewuser(const imcontact &ic) {
 	ev->addParam("hpassword", md5pass);
 
 	ev->addParam("editfriend_add_1_user", c->getnick().substr(0, npos));
-	httpcli.SendEvent(ev);
+
 	sent[ev] = reqAddFriend;
+	httpcli.SendEvent(ev);
     }
 }
 
@@ -332,6 +336,7 @@ void ljhook::removeuser(const imcontact &ic) {
     icqcontact *c;
 
     if(logged())
+    if(conf.getourid(proto).additional["importfriends"] == "1")
     if(c = clist.get(ic))
     if((npos = c->getnick().find("@lj")) != -1) {
 	string nick = c->getnick().substr(0, npos);
@@ -345,8 +350,8 @@ void ljhook::removeuser(const imcontact &ic) {
 
 	    ev->addParam((string) "editfriend_delete_" + nick, "1");
 
-	    httpcli.SendEvent(ev);
 	    sent[ev] = reqDelFriend;
+	    httpcli.SendEvent(ev);
 	}
     }
 }
@@ -409,8 +414,9 @@ void ljhook::lookup(const imsearchparams &params, verticalmenu &dest) {
 
     } else {
 	HTTPRequestEvent *ev = new HTTPRequestEvent(getfeedurl(params.nick));
-	httpcli.SendEvent(ev);
+
 	sent[ev] = reqLookup;
+	httpcli.SendEvent(ev);
 
 	sdest = &dest;
 	lookfor = params.nick;
@@ -447,8 +453,8 @@ void ljhook::requestfriends() {
     ev->addParam("includefriendof", "1");
     ev->addParam("includebdays", "1");
 
-    httpcli.SendEvent(ev);
     sent[ev] = reqGetFriends;
+    httpcli.SendEvent(ev);
 }
 
 // ----------------------------------------------------------------------------
@@ -593,7 +599,14 @@ void ljhook::messageack_cb(MessageEvent *ev) {
 		for(k = 0; k < clist.count && !found; k++) {
 		    c = (icqcontact *) clist.at(k);
 		    if(c->getdesc().pname == rss) {
-			found = (c->getworkinfo().homepage == getfeedurl(username));
+			icqcontact::workinfo wi = c->getworkinfo();
+
+			if(wi.homepage == getoldfeedurl(username)) {
+			    wi.homepage = getfeedurl(username);
+			    c->setworkinfo(wi);
+			}
+
+			found = (wi.homepage == getfeedurl(username));
 		    }
 		}
 
@@ -733,9 +746,7 @@ void ljhook::logger_cb(LogEvent *ev) {
     switch(ev->getType()) {
 	case LogEvent::PACKET:
 	case LogEvent::DIRECTPACKET:
-#if PACKETDEBUG
 	    face.log(ev->getMessage());
-#endif
 	    break;
 
 	default:
@@ -745,6 +756,10 @@ void ljhook::logger_cb(LogEvent *ev) {
 }
 
 string ljhook::getfeedurl(const string &nick) const {
+    return (string) "http://" + conf.getourid(proto).server + "/users/" + nick + "/data/rss?auth=digest";
+}
+
+string ljhook::getoldfeedurl(const string &nick) const {
     return (string) "http://" + conf.getourid(proto).server + "/users/" + nick + "/rss/";
 }
 
