@@ -1,7 +1,7 @@
 /*
 *
 * centericq single IM contact class
-* $Id: icqcontact.cc,v 1.100 2004/11/09 23:49:59 konst Exp $
+* $Id: icqcontact.cc,v 1.104 2005/01/26 23:52:48 konst Exp $
 *
 * Copyright (C) 2001-2004 by Konstantin Klyagin <konst@konst.org.ua>
 *
@@ -112,7 +112,7 @@ string icqcontact::getdirname() const {
 void icqcontact::clear() {
     fupdated = groupid = fhistoffset = lasttyping = 0;
     finlist = true;
-    modified = false;
+    modified = usepgpkey = false;
     cdesc = contactroot;
 
     binfo = basicinfo();
@@ -162,13 +162,14 @@ void icqcontact::save() {
 		string options;
 		if(binfo.requiresauth) options += "a";
 		if(binfo.authawait) options += "w";
+		if(usepgpkey) options += "p";
 
 		f << nick << endl <<
 		    tosane(binfo.fname) << endl <<
 		    tosane(binfo.lname) << endl <<
 		    tosane(binfo.email) << endl <<
 		    options << endl <<
-		    endl <<
+		    pgpkey << endl <<
 		    tosane(binfo.city) << endl <<
 		    tosane(binfo.state) << endl <<
 		    tosane(binfo.phone) << endl <<
@@ -271,8 +272,9 @@ void icqcontact::load() {
 		case  4:
 		    binfo.requiresauth = (buf.find('a') != -1);
 		    binfo.authawait = (buf.find('w') != -1);
+		    usepgpkey = (buf.find('p') != -1);
 		    break;
-		case  5: break;
+		case  5: pgpkey = buf; break;
 		case  6: binfo.city = buf; break;
 		case  7: binfo.state = buf; break;
 		case  8: binfo.phone = buf; break;
@@ -498,9 +500,13 @@ void icqcontact::scanhistory() {
 void icqcontact::setstatus(imstatus fstatus, bool reflect) {
     if(status != fstatus) {
 	if(!ischannel(cdesc)) {
-	    if(status == offline) {
-		external.exec(imrawevent(imevent::online, cdesc, imevent::incoming));
-		playsound(imevent::online);
+	    if(fstatus != offline && status == offline
+	    || fstatus == offline && status != offline) {
+		imevent::imeventtype et =
+		    status == offline ? imevent::online : imevent::offline;
+
+		external.exec(imrawevent(et, cdesc, imevent::incoming));
+		playsound(et);
 	    }
 
 	} else if(reflect) {
@@ -657,6 +663,25 @@ void icqcontact::setlastip(const string &flastip) {
     modified = true;
 }
 
+string icqcontact::getpgpkey() const {
+    return pgpkey;
+}
+
+void icqcontact::setpgpkey(const string &key) {
+    pgpkey = key;
+    usepgpkey = modified = true;
+    fupdated++;
+}
+
+bool icqcontact::getusepgpkey() const {
+    return usepgpkey;
+}
+
+void icqcontact::setusepgpkey(bool usekey) {
+    usepgpkey = usekey;
+    modified = true;
+}
+
 string icqcontact::getabout() const {
     return about;
 }
