@@ -1,7 +1,7 @@
 /*
 *
 * centericq user interface class
-* $Id: icqface.cc,v 1.234 2004/11/12 14:41:45 konst Exp $
+* $Id: icqface.cc,v 1.241 2005/02/01 00:12:58 konst Exp $
 *
 * Copyright (C) 2001-2004 by Konstantin Klyagin <konst@konst.org.ua>
 *
@@ -33,6 +33,7 @@
 #include "imlogger.h"
 #include "irchook.h"
 #include "imexternal.h"
+#include "impgp.h"
 
 const char *stryesno(bool b) {
     return b ? _("yes") : _("no");
@@ -235,6 +236,7 @@ int icqface::contextmenu(icqcontact *c) {
     int ret = 0, i;
     static int lastr = 0;
     imcontact cont;
+    char buf[64];
 
     if(!c) return 0;
 
@@ -280,17 +282,26 @@ int icqface::contextmenu(icqcontact *c) {
 	    sizeWArea.y1+6, conf.getcolor(cp_main_text)));
 
 	if(c->getdesc().pname != rss)
-	    actnames[ACT_MSG]       = getmenuitem(_("Send a message"), 25, key_compose, section_contact);
-	actnames[ACT_HISTORY]   = getmenuitem(_("Event history"), 25, key_history, section_contact);
-	actnames[ACT_REMOVE]    = getmenuitem(_("Remove user"), 25, key_remove, section_contact);
-	actnames[ACT_INFO]      = getmenuitem(_("User's details"), 25, key_info, section_contact);
-	actnames[ACT_EXTERN]    = getmenuitem(_("External actions.."), 25, key_contact_external_action, section_contact);
-	if(lst.inlist(c, csignore))
-	    actnames[ACT_IGNORE]    = getmenuitem(_("Unset ignore user"), 25, key_ignore, section_contact);
-	    else
-		actnames[ACT_IGNORE]    = getmenuitem(_("Ignore user"), 25, key_ignore, section_contact);
+	    actnames[ACT_MSG] = getmenuitem(_("Send a message"), 25, key_compose, section_contact);
+
+	actnames[ACT_HISTORY] = getmenuitem(_("Event history"), 25, key_history, section_contact);
+	actnames[ACT_REMOVE] = getmenuitem(_("Remove user"), 25, key_remove, section_contact);
+	actnames[ACT_INFO] = getmenuitem(_("User's details"), 25, key_info, section_contact);
+	actnames[ACT_EXTERN] = getmenuitem(_("External actions.."), 25, key_contact_external_action, section_contact);
+
+	actnames[ACT_IGNORE] = getmenuitem(lst.inlist(c, csignore) ?
+	    _("Unset ignore user") : _("Ignore user"), 25, key_ignore,
+		section_contact);
+
+	actnames[ACT_PGPKEY] = c->getpgpkey().empty() ?
+	    _(" Assign PGP key..") : _(" Unassign PGP key");
+
+	sprintf(buf, _(" Turn PGP encryption %s"), c->getusepgpkey() ? "OFF" : "ON");
+	actnames[ACT_PGPSWITCH] = buf;
+
 	if(c->getdesc().pname == rss)
-	    actnames[ACT_PING]      = getmenuitem(_("Force check"), 25, key_rss_check, section_contact);
+	    actnames[ACT_PING] = getmenuitem(_("Force check"), 25,
+		key_rss_check, section_contact);
 
     }
 
@@ -323,6 +334,14 @@ int icqface::contextmenu(icqcontact *c) {
 	if(capab.count(hookcapab::authrequests)) actions.push_back(ACT_AUTH);
 	if(capab.count(hookcapab::files)) actions.push_back(ACT_FILE);
 
+    #ifdef HAVE_GPGME
+	if(capab.count(hookcapab::pgp)) {
+	    actions.push_back(ACT_PGPKEY);
+	    if(pgp.havekey(c->getpgpkey()))
+		actions.push_back(ACT_PGPSWITCH);
+	}
+    #endif
+
 	if(!actions.empty())
 	    actions.push_back(0);
 
@@ -942,6 +961,29 @@ void icqface::infogeneral(dialogbox &db, icqcontact *c) {
     workarealine(sizeWArea.y1+8);
     workarealine(sizeWArea.y1+12);
 
+#ifdef HAVE_GPGME
+    if(gethook(c->getdesc().pname).getCapabs().count(hookcapab::pgp))
+    if(!c->getpgpkey().empty()) {
+	buf = (string) "[" + string(5, ' ') + c->getpgpkey() + ": ";
+	
+	if(pgp.havekey(c->getpgpkey())) {
+	    buf += _("found");
+	    buf += ", ";
+	    buf += (pgp.enabled(c) ? _("used") : _("not used"));
+	} else {
+	    buf += _("not found");
+	}
+
+	buf += " ]";
+
+	mainw.write(sizeWArea.x2-buf.size()-1, sizeWArea.y1+11,
+	    conf.getcolor(cp_main_text), buf);
+
+	mainw.write(sizeWArea.x2-buf.size()+1, sizeWArea.y1+11,
+	    conf.getcolor(cp_main_highlight), "PGP");
+    }
+#endif
+
     mainw.write(sizeWArea.x1+2, sizeWArea.y1+2, conf.getcolor(cp_main_highlight), _("Nickname"));
     mainw.write(sizeWArea.x1+2, sizeWArea.y1+3, conf.getcolor(cp_main_highlight), _("Name"));
     mainw.write(sizeWArea.x1+2, sizeWArea.y1+4, conf.getcolor(cp_main_highlight), _("E-mail"));
@@ -952,7 +994,6 @@ void icqface::infogeneral(dialogbox &db, icqcontact *c) {
     mainw.write(sizeWArea.x1+2, sizeWArea.y1+10, conf.getcolor(cp_main_highlight), _("Age"));
     mainw.write(sizeWArea.x1+2, sizeWArea.y1+12, conf.getcolor(cp_main_highlight), _("Languages"));
     mainw.write(sizeWArea.x1+2, sizeWArea.y1+13, conf.getcolor(cp_main_highlight), _("Last IP"));
-
     mainw.write(sizeWArea.x1+14, sizeWArea.y1+2, conf.getcolor(cp_main_text), c->getnick());
     mainw.write(sizeWArea.x1+14, sizeWArea.y1+3, conf.getcolor(cp_main_text), bi.fname + " " + bi.lname);
     mainw.write(sizeWArea.x1+14, sizeWArea.y1+4, conf.getcolor(cp_main_text), bi.email);
@@ -970,6 +1011,7 @@ void icqface::infogeneral(dialogbox &db, icqcontact *c) {
     mainw.write(sizeWArea.x1+14, sizeWArea.y1+13, conf.getcolor(cp_main_text), c->getlastip());
 
     time_t ls = c->getlastseen();
+    buf = "";
 
     if(c->getstatus() == offline) {
 	mainw.write(sizeWArea.x1+2, sizeWArea.y1+14, conf.getcolor(cp_main_highlight), _("Last seen"));
@@ -1422,19 +1464,9 @@ bool icqface::changestatus(vector<protocolname> &pnames, imstatus &st) {
 	mst.push_back(freeforchat);
 	mst.push_back(invisible);
 
-	static string statustext[8] = {
-	    _(" [o] Online"),
-	    _(" [_] Offline"),
-	    _(" [a] Away"),
-	    _(" [d] Do not disturb"),
-	    _(" [n] Not available"),
-	    _(" [c] Occupied"),
-	    _(" [f] Free for chat"),
-	    _(" [i] Invisible")
-	};
-
 	for(im = mst.begin(); im != mst.end(); ++im) {
-	    m.additem(0, *im, statustext[im-mst.begin()]);
+	    string sst = (string) " [" + imstatus2char[*im] + "] " + imstatus2str(*im);
+	    m.additem(0, *im, sst);
 
 	    if(pnames.size() == 1)
 	    if(gethook(pnames.front()).getstatus() == *im)
@@ -1944,7 +1976,6 @@ void icqface::status(const string &text) {
 
     attrset(conf.getcolor(cp_status));
     mvhline(LINES-1, 0, ' ', COLS);
-
     kwriteatf(0, LINES-1, conf.getcolor(cp_status), "%s", t.c_str());
 }
 
@@ -2012,7 +2043,7 @@ void icqface::quickfind(verticalmenu *multi) {
 		break;
 
 	    default:
-		if(isprint(k) || (k == ALT('s'))) {
+		if(isprint(k) || (key2action(k, section_contact) == key_quickfind)) {
 		    i = cm->getpos() + (multi ? 1 : 2);
 
 		    if(isprint(k)) {
@@ -2192,10 +2223,10 @@ bool icqface::eventedit(imevent &ev) {
     saveworkarea();
     clearworkarea();
 
-    workarealine(sizeWArea.y1+2);
+    peerinfo(2, ev.getcontact());
 
     mainw.writef(sizeWArea.x1+2, sizeWArea.y1, conf.getcolor(cp_main_highlight),
-	_("Outgoing %s to %s"), streventname(ev.gettype()), ev.getcontact().totext().c_str());
+	_("Outgoing %s"), streventname(ev.gettype()));
 
     showeventbottom(ev.getcontact());
 
@@ -2212,7 +2243,7 @@ bool icqface::eventedit(imevent &ev) {
 	auto_ptr<char> p(editor.save("\r\n"));
 	*m = immessage(ev.getcontact(), imevent::outgoing, p.get());
 
-	if((c = clist.get(ev.getcontact())) && (msg != p.get()))
+	if(c = clist.get(ev.getcontact()))
 	    c->setpostponed(r ? "" : p.get());
 
     } else if(ev.gettype() == imevent::xml) {
@@ -2234,7 +2265,7 @@ bool icqface::eventedit(imevent &ev) {
 	    if(!setljparams(m))
 		continue;
 
-	    if((c = clist.get(ev.getcontact())) && (msg != p.get()))
+	    if(c = clist.get(ev.getcontact()))
 		c->setpostponed(r ? "" : p.get());
 
 	    break;
@@ -2278,7 +2309,7 @@ bool icqface::eventedit(imevent &ev) {
 	auto_ptr<char> p(editor.save("\r\n"));
 	*m = imsms(ev.getcontact(), imevent::outgoing, p.get(), m->getphone());
 
-	if((c = clist.get(ev.getcontact())) && (msg != p.get()))
+	if(c = clist.get(ev.getcontact()))
 	    c->setpostponed(r ? "" : p.get());
 
     } else if(ev.gettype() == imevent::authorization) {
@@ -2472,7 +2503,7 @@ void icqface::renderchathistory() {
     }
 
     while(events.size() > chatlines) {
-	delete events.front();
+	delete *events.begin();
 	events.erase(events.begin());
     }
 
@@ -2514,7 +2545,7 @@ void icqface::renderchathistory() {
 	}
 
 	delete events.back();
-	events.erase(events.end()-1);
+	events.pop_back();
     }
 
     chatmargin = sizeWArea.y1+chatlines;
@@ -2540,6 +2571,39 @@ void icqface::renderchathistory() {
 	    count++;
 	}
     }
+
+    peerinfo(chatlines+1, passinfo);
+}
+
+void icqface::peerinfo(int line, const imcontact &ic) {
+    workarealine(sizeWArea.y1+line);
+
+    icqcontact *c = clist.get(ic);
+    if(!c) return;
+
+    string text = conf.getprotocolname(passinfo.pname) + " " + c->getdispnick();
+    int maxsize = sizeWArea.x2-sizeWArea.x1-10;
+    bool pgpon = false;
+
+    if(text.size() > maxsize) {
+	text.erase(maxsize);
+	text += "..";
+    }
+
+#ifdef HAVE_GPGME
+    if(pgpon = pgp.enabled(passinfo))
+	text += string(4, ' ');
+#endif
+
+    text = (string) "[ " + text + " ]";
+
+    kwriteatf(sizeWArea.x2-text.size()-1, sizeWArea.y1+line,
+	conf.getcolor(cp_main_text), "%s", text.c_str());
+
+    if(pgpon) {
+	kwriteatf(sizeWArea.x2-6, sizeWArea.y1+line,
+	    conf.getcolor(cp_main_highlight), "PGP");
+    }
 }
 
 void icqface::chat(const imcontact &ic) {
@@ -2561,7 +2625,7 @@ void icqface::chat(const imcontact &ic) {
     muins.push_back(passinfo);
 
     chatlines = (int) ((sizeWArea.y2-sizeWArea.y1)*0.75);
-    workarealine(sizeWArea.y1+chatlines+1);
+//    workarealine(sizeWArea.y1+chatlines+1);
 
     editor.addscheme(cp_main_text, cp_main_text, 0, 0);
     editor.otherkeys = &editmsgkeys;
@@ -3200,11 +3264,25 @@ int icqface::multiplekeys(verticalmenu &m, int k) {
 	case 'x':
 	case 'X':
 	    return -2;
-	case ALT('s'):
-	case ALT('S'):
 	case '/':
 	    return -3;
     }
+
+    if(face.key2action(k, section_contact) == key_quickfind)
+	return -3;
+
+    return -1;
+}
+
+int icqface::findpgpkeys(dialogbox &db, int k) {
+    int r;
+
+    r = face.key2action(k, section_contact);
+    switch(r) {
+	case key_quickfind:
+	    return -3;
+    }
+
     return -1;
 }
 
